# neo-pixel

An importable package to control LED strip using an ESP8266 controller over UDP. This package is a re-write
of [audio-reactive-led-strip](https://github.com/scottlawsonbc/audio-reactive-led-strip) project with Object oriented
classes and better programmatic control over state of controller. 